# Test Coverage Report

Generated: Sat 2013-04-06 17:51 SGT

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 102 | 72 | 22 | 90.0%
subscribe.__init__ | 1 | 1 | 0 | 100.0%
subscribe.forms | 27 | 24 | 3 | 100.0%
subscribe.models | 14 | 8 | 6 | 100.0%
subscribe.templatetags.subscribe_tags | 18 | 14 | 3 | 93.3%
subscribe.tests.test_app.models | 5 | 2 | 3 | 100.0%
subscribe.views | 37 | 23 | 7 | 76.7%

Excluded packages and modules
Error packages and modules